@@ -136,8 +136,7 @@ class RemainingMinSet:
             found_kmers.append(kmer)
         return found_kmers
 
-if __name__ == '__main__':
-
+def main():
     args = get_args()
     
     #--------#
@@ -376,3 +375,7 @@ if __name__ == '__main__':
                 SeqIO.write([seq], f, "fasta")
     
     logging.info("Successfully generated final minimal set")
+
+if __name__ == '__main__':
+
+    main()
\ No newline at end of file
